#ifndef __PCFX_INPUT_MOUSE_H
#define __PCFX_INPUT_MOUSE_H

extern const IDIISG PCFX_MouseIDII;

PCFX_Input_Device *PCFXINPUT_MakeMouse(int which);

#endif
